@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2022-03-08 15:25:34
+@LastEditTime: 2022-06-15 10:30:00
 @LastEditors: HuangJianYi
 :description: App相关
 """
@@ -141,11 +141,12 @@ class CheckGmPowerHandler(SevenBaseHandler):
         store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
         if not store_user_nick:
             return self.reponse_json_success(is_power)
-        app_info = AppInfoModel(context=self).get_entity("user_nick=%s", params=store_user_nick)
+        app_info = AppInfoModel(context=self).get_entity("store_user_nick=%s", params=store_user_nick)
         if not app_info:
             is_power = False
-        if app_info.is_custom == 1:
-            is_power = True
+        else:
+            if app_info.is_custom == 1:
+                is_power = True
         return self.reponse_json_success(is_power)
 
 
@@ -167,7 +168,7 @@ class GetAppidByGmHandler(SevenBaseHandler):
         if not store_user_nick:
             return self.reponse_json_success(app_id)
         is_power = False
-        app_info = AppInfoModel(context=self).get_entity("user_nick=%s", params=store_user_nick)
+        app_info = AppInfoModel(context=self).get_entity("store_user_nick=%s", params=store_user_nick)
         if app_info and app_info.is_custom == 1:
             is_power = True
         if is_power == True:
